import { Server } from '../types';

const STORAGE_KEY = 'proxmox_servers';

export const storage = {
  getServers: (): Server[] => {
    try {
      const data = localStorage.getItem(STORAGE_KEY);
      return data ? JSON.parse(data) : [];
    } catch (error) {
      console.error('Error reading servers:', error);
      return [];
    }
  },

  saveServers: (servers: Server[]): void => {
    try {
      localStorage.setItem(STORAGE_KEY, JSON.stringify(servers));
      // Dispatch storage event to notify other tabs/windows
      window.dispatchEvent(new StorageEvent('storage', {
        key: STORAGE_KEY,
        newValue: JSON.stringify(servers),
        url: window.location.href
      }));
    } catch (error) {
      console.error('Error saving servers:', error);
    }
  },

  addServer: (server: Omit<Server, 'id' | 'created_at' | 'updated_at'>): Server => {
    const servers = storage.getServers();
    const newServer: Server = {
      ...server,
      id: crypto.randomUUID(),
      created_at: new Date().toISOString(),
      updated_at: new Date().toISOString()
    };
    
    servers.push(newServer);
    storage.saveServers(servers);
    return newServer;
  },

  deleteServer: (id: string): void => {
    const servers = storage.getServers();
    const filteredServers = servers.filter(server => server.id !== id);
    storage.saveServers(filteredServers);
  }
};